=======
History
=======

0.4.0 (5-2-2017)
----------------

- Implement the Thread Settings API.

0.3.0 (4-2-2017)
----------------

- Add automatic attachment hosting using the internal server
- Add proper handling of Messenger API errors

0.2.1 (1-2-2017)
----------------

- Update dependency versions to fix VersionConflict in Travis CI.

0.2.0 (1-2-2017)
----------------

- Implement the Send API. All non-beta templates and messages are supported
  (except for the airline templates).

0.1.0 (25-12-2016)
------------------

- Implement the Webhook API, with handling of all non-beta event types
  excepting the 'message echo' event, which will be added upon completion of
  the Send API implementation.

0.0.0 (22-12-2016)
------------------

- Initial development version.
